@@ -1,15 +1,17 @@
 from typing import List, Dict, Optional
 
+from .metasv import MetaSV
 from .provider import Provider
 from .whatsonchain import WhatsOnChain
-from ..constants import Chain
+from ..constants import Chain, METASV_TOKEN
 
 
 class Service:
 
     def __init__(self, chain: Chain = Chain.MAIN, provider: Optional[Provider] = None):
         self.chain: Chain = chain
-        self.provider = provider or WhatsOnChain(self.chain)
+        default_provider = MetaSV(METASV_TOKEN) if chain == Chain.MAIN and METASV_TOKEN else WhatsOnChain(self.chain)
+        self.provider = provider or default_provider
 
     def get_unspents(self, **kwargs) -> List[Dict]:
         """kwargs will pass the following at least
